[−][src]Struct aligned_bytes::AlignedBox
Aligned heap allocation
Implementations
impl<T> AlignedBox<T>[src]
pub fn new(x: T, align: usize) -> Self[src]
Allocates memory on the heap with specified alignment and then places x into it.
This doesn't actually allocate if T is zero-sized.
impl<T: ?Sized> AlignedBox<T>[src]
pub fn into_raw(this: Self) -> (*mut T, usize)[src]
Consumes the box, returning a raw pointer and alignment.
pub unsafe fn from_raw(ptr: *mut T, align: usize) -> Self[src]
Constructs a aligned box from a raw pointer and alignment
Safety
ptrmust be non-null and well aligned foralignptrmust be allocated with the global allocator
pub fn alignment(this: &Self) -> usize[src]
Returns the alignment of the box